@@ -31,17 +31,21 @@
 class QWebEngineSettings;
 class QWebEngineScript;
 class QWebEngineView;
+class QCompleter;
+class QStringListModel;
 
 class MainWindow : public QMainWindow
 {
     Q_OBJECT
 public:
-    explicit MainWindow(const QCommandLineParser &arg_parser, QWidget *parent = nullptr);
+    explicit MainWindow(const QCommandLineParser &argParser, QWidget *parent = nullptr);
     explicit MainWindow(const QUrl &url, QWidget *parent = nullptr);
     ~MainWindow() override;
 
 public slots:
     void listHistory();
+    void openHistoryPage();
+    bool handleHistoryRequest(const QUrl &url);
     void findBackward();
     void findForward();
     void loading();
@@ -51,6 +55,7 @@ public slots:
     void openLinkInNewTab(const QUrl &url);
     void openDevTools();
     void openSettings();
+    bool handleSettingsRequest(const QUrl &url);
     bool restoreSavedTabs();
 
 protected:
@@ -67,7 +72,20 @@ private:
     QLineEdit *searchBox {};
     QMenu *bookmarks {};
     QMenu *history {};
+    QCompleter *historyCompleter {};
+    QStringListModel *historyCompletionModel {};
+    QStringList historyCompletionHosts;
     QProgressBar *progressBar {};
+    QString searchEngine;
+    QString searchEngineCustom;
+    QString lastAddressInput;
+    QUrl lastAddressUrl;
+    bool lastAddressMaySearch {};
+    bool lastAddressExplicitScheme {};
+    bool completingHistory {};
+    int lastAddressEditLength {};
+    bool lastAddressEditWasDeletion {};
+    QByteArray normalGeometry;
     QSettings settings;
     QString homeAddress;
     QToolBar *toolBar {};
@@ -79,7 +97,7 @@ private:
     bool cookiesEnabled {true};
     bool restoredTabs {};
     const QCommandLineParser *args;
-    QList<QUrl> closedTabs;
+    QList<QPair<QUrl, QIcon>> closedTabs;
     QPointer<QMainWindow> devToolsWindow;
     QPointer<QWebEngineView> devToolsView;
     QWebEngineScript cookieScript;
@@ -114,8 +132,13 @@ private:
     void setupMenuConnections(QMenu *menu);
     void buildMenu();
     void centerWindow();
+    void clearHistoryEntries();
     void connectAddress(const QAction *action, const QMenu *menu);
     void displaySite(QString url = {}, const QString &title = {});
+    void displaySearchResults(const QString &query);
+    void openFromAddressBarText(const QString &input);
+    QString buildSettingsPageHtml();
+    QString buildHistoryPageHtml();
     void focusAddressBar();
     void focusAddressBarIfBlank();
     void applyWebSettings();
@@ -126,6 +149,15 @@ private:
     void openBrowseDialog();
     void openQuickInfo();
     void openBookmarksEditor();
+    void openFromAddressBar();
+    bool isLocalHostInput(const QString &input) const;
+    void openSettingsPage();
+    void openSavedTab(const QUrl &url, bool makeCurrent);
+    void removeHistoryEntry(int index);
+    void refreshHistoryCompleter();
+    void renderHistoryPage(WebView *view);
+    void renderSettingsPage(WebView *view);
+    QString searchUrlForQuery(const QString &query) const;
     void saveMenuItems(const QMenu *menu, int offset);
     void setConnections();
     void showFullScreenNotification();
